#!/usr/bin/env python
###############################################################################
#
# Project:  GDAL/OGR Test Suite
# Purpose:  Generate GeoPackage raster
# Author:   Even Rouault, <even dot rouault at spatialys dot com>
#
###############################################################################
# Copyright (c) 2014, Even Rouault <even dot rouault at spatialys dot com>
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.
###############################################################################

import os
import urllib

if not os.path.exists('utm.tif'):
    print('Downloading utm.tif...')
    urllib.urlretrieve ("http://download.osgeo.org/gdal/data/gtiff/utm.tif", "utm_tmp.tif")
    os.rename('utm_tmp.tif', 'utm.tif')

if not os.path.exists('small_world.tif'):
    print('Downloading small_world.tif...')
    urllib.urlretrieve ("http://download.osgeo.org/gdal/data/gtiff/small_world.tif", "small_world_tmp.tif")
    os.rename('small_world_tmp.tif', 'small_world.tif')
    
if not os.path.exists('stefan_full_rgba.tif'):
    print('Downloading stefan_full_rgba.tif...')
    urllib.urlretrieve ("http://svn.osgeo.org/gdal/trunk/autotest/gcore/data/stefan_full_rgba.tif", "stefan_full_rgba_tmp.tif")
    os.rename('stefan_full_rgba_tmp.tif', 'stefan_full_rgba.tif')

os.putenv('OGR_SQLITE_SYNCHRONOUS', 'OFF') # helps for performance on some system with poort EXT4 implementation

# 2x2 256x256 single band JPEG tiles
os.system("gdal_translate -of GPKG utm.tif utm_jpeg_one_band.gpkg -co TILE_FORMAT=JPEG")

# 2x2 256x256 single band PNG tiles
os.system("gdal_translate -of GPKG utm.tif utm_png_one_band.gpkg -co TILE_FORMAT=PNG")

# Grey level + alpha in PNG tiles
os.system("gdal_translate -of GPKG utm.tif utm_png_grey_and_alpha.gpkg -co TILE_FORMAT=PNG -srcwin 0 0 200 200")

# 2x1 256x200 PNG tiles. One with 3 bands, the other one with 4 bands
os.system("gdal_translate -of GPKG small_world.tif small_world_png.gpkg -co TILE_FORMAT=PNG -co BLOCKYSIZE=200")

# Same with overview
os.system("gdal_translate -of GPKG small_world.tif small_world_png_with_ovr.gpkg -co TILE_FORMAT=PNG -co BLOCKYSIZE=200")
os.system("gdaladdo -r cubic small_world_png_with_ovr.gpkg 2")

# 2x1 256x200 PNG tiles. One in PNG-8, the other one with 4 bands
os.system("gdal_translate -of GPKG small_world.tif small_world_png8.gpkg -co TILE_FORMAT=PNG8 -co BLOCKYSIZE=200")

# Same with overview with now power of two factor
os.system("gdal_translate -of GPKG small_world.tif small_world_png_gpkg_zoom_other.gpkg -co TILE_FORMAT=PNG -co BLOCKYSIZE=200")
os.system("gdaladdo -r cubic small_world_png_gpkg_zoom_other.gpkg 3")

# 2x1 256x200 tiles. One with 3 bands in JPEG, the other one with 4 bands in PNG
os.system("gdal_translate -of GPKG small_world.tif small_world_jpg_png.gpkg -co BLOCKYSIZE=200")

# Same but we remove the extent in gpkg_contents
os.system("gdal_translate -of GPKG small_world.tif small_world_jpg_png_no_extent.gpkg -co BLOCKYSIZE=200")
os.system('ogrinfo small_world_jpg_png_no_extent.gpkg -sql "UPDATE gpkg_contents SET min_x=null, min_y=null, max_x=null, max_y=null"')

# 2x1 256x200 tiles. One with 3 bands in WEBP, the other one with 4 bands in WEBP
os.system("gdal_translate -of GPKG small_world.tif small_world_webp.gpkg -co TILE_FORMAT=WEBP -co BLOCKYSIZE=200")

# GoogleMapsCompatible tiling scheme
os.system("gdal_translate -of GPKG small_world.tif small_world_googlemapscompatible.gpkg -co TILING_SCHEME=GoogleMapsCompatible -co ZOOM_LEVEL_STRATEGY=UPPER")

# GoogleCRS84Quad tiling scheme
os.system("gdal_translate -of GPKG small_world.tif small_world_googlecrs84quad.gpkg -co TILING_SCHEME=GoogleCRS84Quad -co ZOOM_LEVEL_STRATEGY=UPPER")

# Same but at zoom_level 3
os.system("gdal_translate -of GPKG small_world.tif small_world_googlecrs84quad_bigger.gpkg -co TILING_SCHEME=GoogleCRS84Quad -co ZOOM_LEVEL_STRATEGY=UPPER -outsize 400% 400%")

# 4 band with intermediate alpha value in PNG
os.system("gdal_translate -of GPKG stefan_full_rgba.tif stefan_full_rgba_png.gpkg -co TILE_FORMAT=PNG -a_ullr 0 0 1 -1")

# 4 band with intermediate alpha value in WEBP
os.system("gdal_translate -of GPKG stefan_full_rgba.tif stefan_full_rgba_webp.gpkg -co TILE_FORMAT=WEBP -a_ullr 0 0 1 -1")

# Completely transparent tiles (thus missing) within the raster
os.system("gdal_translate -of GPKG stefan_full_rgba.tif stefan_full_rgba_missing_tiles.gpkg -co BLOCKSIZE=16 -a_ullr 0 0 1 -1")

# Two raster tables
os.system("gdal_translate -of GPKG small_world.tif small_world_and_byte.gpkg")
os.system("gdal_translate -of GPKG utm.tif small_world_and_byte.gpkg -co APPEND_SUBDATASET=YES")
